
;include "F:\Projects\RetroGFX\cpu\language.inc"

;-----

;------------------
;display current PC
;------------------
macro PrintPC
{
bits = 16
display 'Current offset is $'
repeat bits/4
d = '0' + $ shr (bits-%*4) and 0Fh
if d > '9'
d = d + 'A'-'9'-1
end if
display d
end repeat
display 13,10
 }

;-----

macro verify a
{
  if ?s eq 0
    'Error: ' a
  end if
}

;-----

macro verify.i i
{
  if ~ i eqtype 0
    'Number expected:' i
  end if
}

;-----

macro verify.n n, min, max {
  if n<min | n>max
    'Number exceeds range:' min-max
  end if
} 

;-----

macro verify.u8 n  { verify.n n, 0, 255 } 
macro verify.i8 n  { verify.n n, -128, 127 }
macro verify.u16 n { verify.n n, 0, 65535 } 
macro verify.i16 n { verify.n n, -32768, 32767 } 
macro verify.u32 n { verify.n n, 0, 65535*256 } 

;===============================================================================

macro nop     { dw $00 }      ;no operation
macro res     { dw $01 }      ;software reset
macro sei     { dw $02 }      ;disable irq interrupts
macro cli     { dw $03 }      ;enable irq interrupt
macro php     { dw $04 }      ;push SR
macro plp     { dw $05 }      ;pull SR
macro clc     { dw $08 }      ;clear carry flag
macro clz     { dw $09 }      ;clear zero flag
macro clv     { dw $0A }      ;clear overflow flag
macro cmi     { dw $0B }      ;clear sign flag (N)
macro sec     { dw $0C }      ;set carry flag
macro sez     { dw $0D }      ;set zero flag
macro sev     { dw $0E }      ;set overflow flag
macro smi     { dw $0F }      ;set sign flag (N)
macro rts     { dw $10 }      ;return subroutine
macro rti     { dw $11 }      ;return interrupt
macro phl8    { dw $12 }      ;push a8,x8,y8
macro phl16   { dw $13 }      ;push a16,x16,y16
macro phl32   { dw $14 }      ;push a32,x32,y32
macro pll8    { dw $15 }      ;pull y8,x8,a8
macro pll16   { dw $16 }      ;pull y16,x16,a16
macro pll32   { dw $17 }      ;pull y32,x32,a32

;----------------------
;REGISTER DATA TRANSFER
;----------------------
macro tax     { dw $22}
macro tax8    { dw $20}
macro tax16   { dw $21}
macro tax32   { dw $22}

macro tay     { dw $26}
macro tay8    { dw $24}
macro tay16   { dw $25}
macro tay32   { dw $26}

macro txa     { dw $2E}
macro txa8    { dw $2C}
macro txa16   { dw $2D}
macro txa32   { dw $2E}

macro txy     { dw $32}
macro txy8    { dw $30}
macro txy16   { dw $31}
macro txy32   { dw $32}

macro tya     { dw $3A}
macro tya8    { dw $38}
macro tya16   { dw $39}
macro tya32   { dw $3A}

macro tyx     { dw $3E}
macro tyx8    { dw $3C}
macro tyx16   { dw $3D}
macro tyx32   { dw $3E}

;-------------
;REGISTER PUSH
;-------------
macro pha     { dw $3A}
macro pha8    { dw $38}
macro pha16   { dw $39}
macro pha32   { dw $3A}

macro phx     { dw $3E}
macro phx8    { dw $3C}
macro phx16   { dw $3D}
macro phx32   { dw $3E}

macro phy     { dw $42}
macro phy8    { dw $40}
macro phy16   { dw $41}
macro phy32   { dw $42}

;-------------
;REGISTER PULL
;-------------
macro pla     { dw $46}
macro pla8    { dw $44}
macro pla16   { dw $45}
macro pla32   { dw $46}

macro plx     { dw $4A}
macro plx8    { dw $48}
macro plx16   { dw $49}
macro plx32   { dw $4A}

macro ply     { dw $4E}
macro ply8    { dw $4C}
macro ply16   { dw $4D}
macro ply32   { dw $4E}

;------------------
;REGISTER INCREMENT
;------------------
macro ina     { dw $52 }
macro ina8    { dw $50 }
macro ina16   { dw $51 }
macro ina32   { dw $52 }

macro inx     { dw $56 }
macro inx8    { dw $54 }
macro inx16   { dw $55 }
macro inx32   { dw $56 }

macro iny     { dw $5A }
macro iny8    { dw $58 }
macro iny16   { dw $59 }
macro iny32   { dw $5A }

;------------------
;REGISTER DECREMENT
;------------------
macro dea     { dw $5E }
macro dea8    { dw $5C }
macro dea16   { dw $5D }
macro dea32   { dw $5E }

macro dex     { dw $62 }
macro dex8    { dw $60 }
macro dex16   { dw $61 }
macro dex32   { dw $62 }

macro dey     { dw $66 }
macro dey8    { dw $64 }
macro dey16   { dw $65 }
macro dey32   { dw $66 }

;----------------
;REGISTER COMPARE
;----------------
macro cax     { dw $6A }
macro cax8    { dw $68 }
macro cax16   { dw $69 }
macro cax32   { dw $6A }

macro cay     { dw $6E }
macro cay8    { dw $6A }
macro cay16   { dw $6D }
macro cay32   { dw $6E }

macro cxa     { dw $72 }
macro cxa8    { dw $70 }
macro cxa16   { dw $71 }
macro cxa32   { dw $72 }

macro cxy     { dw $76 }
macro cxy8    { dw $74 }
macro cxy16   { dw $75 }
macro cxy32   { dw $76 }

macro cya     { dw $7A }
macro cya8    { dw $78 }
macro cya16   { dw $79 }
macro cya32   { dw $7A }

macro cyx     { dw $7E }
macro cyx8    { dw $7C }
macro cyx16   { dw $7D }
macro cyx32   { dw $7E }

;----------------
;REGISTER JMP,JSR
;----------------
macro jpa     { dw $80 }
macro jpx     { dw $81 }
macro jpy     { dw $82 }

macro jsa     { dw $83 }
macro jsx     { dw $84 }
macro jsy     { dw $85 }




;--------------------------------------


;--------------
;BRANCH (8-BIT)
;--------------
macro bxx8 o, a
 { dw o, (254-($-a)) and $FF }

macro bra a { bxx8 $06, a }
macro bra8 a { bxx8 $06, a }

macro bpl a { bxx8 $F0, a }
macro bvc a { bxx8 $F1, a }
macro bcc a { bxx8 $F2, a }
macro bne a { bxx8 $F3, a }
macro bmi a { bxx8 $F4, a }
macro bvs a { bxx8 $F5, a }
macro bcs a { bxx8 $F6, a }
macro beq a { bxx8 $F7, a }

macro bpl8 a { bxx8 $F0, a }
macro bvc8 a { bxx8 $F1, a }
macro bcc8 a { bxx8 $F2, a }
macro bne8 a { bxx8 $F3, a }
macro bmi8 a { bxx8 $F4, a }
macro bvs8 a { bxx8 $F5, a }
macro bcs8 a { bxx8 $F6, a }
macro beq8 a { bxx8 $F7, a }

;---------------
;BRANCH (16-BIT)
;---------------
macro bxx16 o, a
 { dw o, (65534-($-a)) and $FFFF }

macro bra16 a { bxx16 $07, a }

macro bpl16 a { bxx16 $F8, a }
macro bvc16 a { bxx16 $F9, a }
macro bcc16 a { bxx16 $FA, a }
macro bne16 a { bxx16 $FB, a }
macro bmi16 a { bxx16 $FC, a }
macro bvs16 a { bxx16 $FD, a }
macro bcs16 a { bxx16 $FE, a }
macro beq16 a { bxx16 $FF, a }


;--------------------------------------


;-------------------------------------------------------------------------------
;GROUP I INSTRUCTIONS
;--------------------
GROUP1 =$0100

OP_LDA8   =GROUP1+$00
OP_LDA16  =GROUP1+$10
OP_LDA32  =GROUP1+$20
OP_CMP8   =GROUP1+$40
OP_CMP16  =GROUP1+$50
OP_CMP32  =GROUP1+$60
OP_ADC8   =GROUP1+$80
OP_ADC16  =GROUP1+$90
OP_ADC32  =GROUP1+$A0
OP_SBC8   =GROUP1+$C0
OP_SBC16  =GROUP1+$D0
OP_SBC32  =GROUP1+$E0

OP_ADD8   =GROUP1+$100
OP_ADD16  =GROUP1+$110
OP_ADD32  =GROUP1+$120
OP_SUB8   =GROUP1+$140
OP_SUB16  =GROUP1+$150
OP_SUB32  =GROUP1+$160
OP_MUL8   =GROUP1+$180
OP_MUL16  =GROUP1+$190
OP_MUL32  =GROUP1+$1A0
OP_DIV8   =GROUP1+$1C0
OP_DIV16  =GROUP1+$1D0
OP_DIV32  =GROUP1+$1E0

OP_BIT8   =GROUP1+$200
OP_BIT16  =GROUP1+$210
OP_BIT32  =GROUP1+$220
OP_ORA8   =GROUP1+$240
OP_ORA16  =GROUP1+$250
OP_ORA32  =GROUP1+$260
OP_AND8   =GROUP1+$280
OP_AND16  =GROUP1+$290
OP_AND32  =GROUP1+$2A0
OP_EOR8   =GROUP1+$2C0
OP_EOR16  =GROUP1+$2D0
OP_EOR32  =GROUP1+$2E0

OP_ASL8   =GROUP1+$300
OP_ASL16  =GROUP1+$310
OP_ASL32  =GROUP1+$320
OP_LSR8   =GROUP1+$340
OP_LSR16  =GROUP1+$350
OP_LSR32  =GROUP1+$360
OP_ROL8   =GROUP1+$380
OP_ROL16  =GROUP1+$390
OP_ROL32  =GROUP1+$3A0
OP_ROR8   =GROUP1+$3C0
OP_ROR16  =GROUP1+$3D0
OP_ROR32  =GROUP1+$3E0

OP_STA8   =GROUP1+$400
OP_STA16  =GROUP1+$410
OP_STA32  =GROUP1+$420
OP_STZ8   =GROUP1+$440
OP_STZ16  =GROUP1+$450
OP_STZ32  =GROUP1+$460
OP_INC8   =GROUP1+$480
OP_INC16  =GROUP1+$490
OP_INC32  =GROUP1+$4A0
OP_DEC8   =GROUP1+$4C0
OP_DEC16  =GROUP1+$4D0
OP_DEC32  =GROUP1+$4E0

OP_LDX8   =GROUP1+$500
OP_LDX16  =GROUP1+$510
OP_LDX32  =GROUP1+$520
OP_CPX8   =GROUP1+$540
OP_CPX16  =GROUP1+$550
OP_CPX32  =GROUP1+$560
OP_STX8   =GROUP1+$580
OP_STX16  =GROUP1+$590
OP_STX32  =GROUP1+$5A0
OP_LDY8   =GROUP1+$5C0
OP_LDY16  =GROUP1+$5D0
OP_LDY32  =GROUP1+$5E0

OP_CPY8   =GROUP1+$600
OP_CPY16  =GROUP1+$610
OP_CPY32  =GROUP1+$620
OP_STY8   =GROUP1+$640
OP_STY16  =GROUP1+$650
OP_STY32  =GROUP1+$660
OP_JMP    =GROUP1+$680
OP_JSR    =GROUP1+$690



;-------------------------------------------------------------------------------

;-------------------------
; GROUP I ADDRESSING MODES
;-------------------------
IMMEDIATE     =0    ;  0  IMM      NOT IMPLEMENTED FOR STA, STZ, INC, DEC
ZEROPAGE      =1    ;  1  ZP
ZEROPAGE_X    =2    ;  2  ZP,X
ZEROPAGE_Y    =3    ;  3  ZP,Y
ZEROPAGE_IX   =4    ;  4  (ZP,X)
ZEROPAGE_I    =5    ;  5  (ZP)
ZEROPAGE_IY   =6    ;  6  (ZP),Y
STKREL        =7    ;  7  SR,S
STKREL_IY     =8    ;  8  (SR,S),Y
ABSOLUTE      =9    ;  9  ABS
ABSOLUTE_X    =10   ; 10  ABS,X
ABSOLUTE_Y    =11   ; 11  ABS,Y
ABSOLUTE_IX   =12   ; 12  (ABS,X)
ABSOLUTE_I    =13   ; 13  (ABS)
ABSOLUTE_IY   =14   ; 14  (ABS),Y

;-------------------------------------------------------------------------------


;-------------------------
;DETERMINE ADDRESSING MODE
;-------------------------

macro o1.6502 name, aaa, [p]
{
common

local i, addrmode
define ?t 0

;------------------
;mode 0   IMMEDIATE
;------------------
match =0 ==a, ?t p

\{
i=a                                   ;make a copy (i) for the output stage
addrmode = IMMEDIATE

  if name eq sta | \			              ;check for: STA,STZ,INC,DEC IMMEDIATE
  name eq stz | \
  name eq inc | \
  name eq dec
    'Error: Not implemented' a          ;ADDRESSING MODE NOT IMPLEMENTED
  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;---------------
;mode 7   STKREL
;---------------

match =0 a=,=s, ?t p

\{
i=a
addrmode = STKREL

define ?t 1
\}

;-------------------------------------------------------------------------------

;------------------
;mode 8   STKREL_IY
;------------------

match =0 (a=,=s)=,=y, ?t p

\{
i=a
addrmode = STKREL_IY

define ?t 1
\}

;-------------------------------------------------------------------------------

;--------------------
;mode 4   ZEROPAGE_IX
;mode 12  ABSOLUTE_IX
;--------------------
match =0 (a=,=x), ?t p

\{
i=a                                   ;make a copy (i) for the output stage

  if a<256                              ;(zp,x)
    addrmode = ZEROPAGE_IX

  else                                  ;(abs,x)
    addrmode = ABSOLUTE_I

  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;-------------------
;mode 2   ZEROPAGE_X
;mode 3   ZEROPAGE_Y
;mode 10  ABSOLUTE_X
;mode 11  ABSOLUTE_Y
;-------------------

match =0 a=,b, ?t p

\{
i=a
verify.i a		                          ; i, ?

  if b eq x                           ;----- i, x -----

    if a<256                          ;----- zero page, x -----
      addrmode = ZEROPAGE_X

    else                              ;----- absolute, x -----
      addrmode = ABSOLUTE_X

    end if

  else if b eq y

    if a<256                          ;----- zero page, y -----
      addrmode = ZEROPAGE_Y

    else                              ;----- absolute, y -----
      addrmode = ABSOLUTE_Y

    end if

    else
      'Error: ' b

  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;-------------------
;mode 5   ZEROPAGE_I
;mode 13  ABSOLUTE_I
;-------------------
match =0 (a), ?t p

\{
i=a                                   ;make a copy (i) for the output stage

  if a<256                              ;(zp)
    addrmode = ZEROPAGE_I

  else                                  ;(abs)
    addrmode = ABSOLUTE_I

  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;--------------------
;mode 6   ZEROPAGE_IY
;mode 14  ABSOLUTE_IY
;--------------------
match =0 (a)=,=y, ?t p

\{
i=a

  if a<256                            ;(zp),y
    addrmode = ZEROPAGE_IY

  else                                ;(abs),y
    addrmode = ABSOLUTE_IY

  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;---------------
;mode 1 ZEROPAGE
;mode 9 ABSOLUTE
;---------------

match =0 a, ?t p

\{
i=a

  if a<256
    addrmode = ZEROPAGE

  else                                ;----- absolute -----
    addrmode = ABSOLUTE

  end if

define ?t 1
\}

;-------------------------------------------------------------------------------

;-----------------------------------
;GENERATE & ASSEMBLE BYTES TO MEMORY
;-----------------------------------

verify name                             ;determine correct mnemonic


;-------------------------------------------------------------------------------
;-------------------------------------------------------------------------------


;---------------
;      LDA
;---------------

;--
;A8
;--
  if name eq lda8                       ;A8
    dw addrmode+OP_LDA8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq lda16                 ;A16
    dw addrmode+OP_LDA16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14

      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq lda32 | name eq lda   ;A32
    dw addrmode+OP_LDA32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      CMP
;---------------

;--
;A8
;--
  if name eq cmp8                       ;A8
    dw addrmode+OP_CMP8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq cmp16                 ;A16
    dw addrmode+OP_CMP16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq cmp32 | name eq cmp   ;A32
    dw addrmode+OP_CMP32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ADC
;---------------

;--
;A8
;--
  if name eq adc8                       ;A8
    dw addrmode+OP_ADC8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq adc16                 ;A16
    dw addrmode+OP_ADC16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq adc32 | name eq adc   ;A32
    dw addrmode+OP_ADC32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      SBC
;---------------

;--
;A8
;--
  if name eq sbc8                       ;A8
    dw addrmode+OP_SBC8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq sbc16                 ;A16
    dw addrmode+OP_SBC16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq sbc32 | name eq sbc   ;A32
    dw addrmode+OP_SBC32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ADD
;---------------

;--
;A8
;--
  if name eq add8                       ;A8
    dw addrmode+OP_ADD8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq add16                 ;A16
    dw addrmode+OP_ADD16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq add32 | name eq add   ;A32
    dw addrmode+OP_ADD32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      SUB
;---------------

;--
;A8
;--
  if name eq sub8                       ;A8
    dw addrmode+OP_SUB8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq sub16                 ;A16
    dw addrmode+OP_SUB16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq sub32 | name eq sub   ;A32
    dw addrmode+OP_SUB32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      MUL
;---------------

;--
;A8
;--
  if name eq mul8                       ;A8
    dw addrmode+OP_MUL8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq mul16                 ;A16
    dw addrmode+OP_MUL16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq mul32 | name eq mul   ;A32
    dw addrmode+OP_MUL32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      DIV
;---------------

;--
;A8
;--
  if name eq div8                       ;A8
    dw addrmode+OP_DIV8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq div16                 ;A16
    dw addrmode+OP_DIV16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq div32 | name eq div   ;A32
    dw addrmode+OP_DIV32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      BIT
;---------------

;--
;A8
;--
  if name eq bit8                       ;A8
    dw addrmode+OP_BIT8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq bit16                 ;A16
    dw addrmode+OP_BIT16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq bit32 | name eq bit   ;A32
    dw addrmode+OP_BIT32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ORA
;---------------

;--
;A8
;--
  if name eq ora8                       ;A8
    dw addrmode+OP_ORA8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq ora16                 ;A16
    dw addrmode+OP_ORA16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq ora32 | name eq ora   ;A32
    dw addrmode+OP_ORA32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      AND
;---------------

;--
;A8
;--
  if name eq and8                       ;A8
    dw addrmode+OP_AND8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq and16                 ;A16
    dw addrmode+OP_AND16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq and32 | name eq and   ;A32
    dw addrmode+OP_AND32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      EOR
;---------------

;--
;A8
;--
  if name eq eor8                       ;A8
    dw addrmode+OP_EOR8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq eor16                 ;A16
    dw addrmode+OP_EOR16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq eor32 | name eq eor   ;A32
    dw addrmode+OP_EOR32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ASL
;---------------

;--
;A8
;--
  if name eq asl8                       ;A8
    dw addrmode+OP_ASL8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq asl16                 ;A16
    dw addrmode+OP_ASL16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq asl32 | name eq asl   ;A32
    dw addrmode+OP_ASL32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      LSR
;---------------

;--
;A8
;--
  if name eq lsr8                       ;A8
    dw addrmode+OP_LSR8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq lsr16                 ;A16
    dw addrmode+OP_LSR16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq lsr32 | name eq lsr   ;A32
    dw addrmode+OP_LSR32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ROL
;---------------

;--
;A8
;--
  if name eq rol8                       ;A8
    dw addrmode+OP_ROL8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq rol16                 ;A16
    dw addrmode+OP_ROL16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq rol32 | name eq rol   ;A32
    dw addrmode+OP_ROL32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      ROR
;---------------

;--
;A8
;--
  if name eq ror8                       ;A8
    dw addrmode+OP_ROR8

      if addrmode <9                    ;byte-sized operands (modes 0-8)
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands (modes 9-14)
        dd i                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y
      end if

;---
;A16
;---
  else if name eq ror16                 ;A16
    dw addrmode+OP_ROR16

      if addrmode =0                    ;word-sized operands
        dw i                            ;mode 0   imm

      else if addrmode <9               ;byte-sized operands
        db i                            ;modes 1-8
                                        ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

;---
;A32
;---
  else if name eq ror32 | name eq ror   ;A32
    dw addrmode+OP_ROR32

      if addrmode =0                    ;byte-sized operands
        dd i                            ;mode 0   imm

      else if addrmode <9               ;modes 1-8
        db i                            ;imm|zp|zp,x|zp,y|(zp,x)|(zp)|(zp),y
                                        ;sr,s|(sr,s),y
      else                              ;dword-sized operands
        dd i                            ;modes 9-14
      end if                            ;abs|abs,x|abs,y|(abs,x)|(abs)|(abs),y

  end if

;===============================================================================
;===============================================================================

;---------------
;      STA
;---------------

;--
;A8
;--
  if name eq sta8                       ;A8

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STA8
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STA8
      dd i

    end if

;---
;A16
;---
  else if name eq sta16                 ;A16

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STA16
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STA16
      dd i

    end if

;---
;A32
;---
  else if name eq sta32 | name eq sta   ;A32

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STA32
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STA32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      STZ
;---------------

;--
;A8
;--
  if name eq stz8                       ;A8

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STZ8
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STZ8
      dd i

    end if

;---
;A16
;---
  else if name eq stz16                 ;A16

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STZ16
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STZ16
      dd i

    end if

;---
;A32
;---
  else if name eq stz32 | name eq stz   ;A32

    if addrmode >0 & addrmode <9
      dw addrmode+OP_STZ32
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_STZ32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      INC
;---------------

;--
;A8
;--
  if name eq inc8                       ;A8

    if addrmode >0 & addrmode <9
      dw addrmode+OP_INC8
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_INC8
      dd i

    end if

;---
;A16
;---
  else if name eq inc16                 ;A16

    if addrmode >0 & addrmode <9
      dw addrmode+OP_INC16
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_INC16
      dd i

    end if

;---
;A32
;---
  else if name eq inc32 | name eq inc   ;A32

    if addrmode >0 & addrmode <9
      dw addrmode+OP_INC32
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_INC32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      DEC
;---------------

;--
;A8
;--
  if name eq dec8                       ;A8

    if addrmode >0 & addrmode <9
      dw addrmode+OP_DEC8
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_DEC8
      dd i

    end if

;---
;A16
;---
  else if name eq dec16                 ;A16

    if addrmode >0 & addrmode <9
      dw addrmode+OP_DEC16
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_DEC16
      dd i

    end if

;---
;A32
;---
  else if name eq dec32 | name eq dec   ;A32

    if addrmode >0 & addrmode <9
      dw addrmode+OP_DEC32
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_DEC32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      LDX
;---------------

;--
;X8
;--
  if name eq ldx8                       ;X8

    if addrmode = 0 | addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_LDX8
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_LDX8
      dd i

    end if

;---
;X16
;---
  else if name eq ldx16                 ;X16

    if addrmode = 0
      dw addrmode+OP_LDX16
      dw i
      
    else if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_LDX16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_LDX16
      dd i

    end if

;---
;X32
;---
  else if name eq ldx32 | name eq ldx   ;X32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_LDX32
      db i

    else if addrmode = 0 | addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_LDX32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      CPX
;---------------

;--
;X8
;--
  if name eq cpx8                       ;X8

    if addrmode = 0 | addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_CPX8
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPX8
      dd i

    end if

;---
;X16
;---
  else if name eq cpx16                 ;X16

    if addrmode = 0
      dw addrmode+OP_CPX16
      dw i

    else if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_CPX16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPX16
      dd i

    end if

;---
;X32
;---
  else if name eq cpx32 | name eq cpx   ;X32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_CPX32
      db i

    else if addrmode = 0 | addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPX32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      STX
;---------------

;--
;X8
;--
  if name eq stx8                       ;X8

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STX8
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STX8
      dd i

    end if

;---
;X16
;---
  else if name eq stx16                 ;X16

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STX16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STX16
      dd i

    end if

;---
;X32
;---
  else if name eq stx32 | name eq stx   ;X32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STX32
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STX32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      LDY
;---------------

;--
;Y8
;--
  if name eq ldy8                       ;Y8

    if addrmode = 0 | addrmode =1 | addrmode =2 | addrmode =4 \
    | addrmode =5 | addrmode =7
      dw addrmode+OP_LDY8
      db i

    else if addrmode =9 | addrmode=10 | addrmode=12 | addrmode=13
      dw addrmode+OP_LDY8
      dd i

    end if

;---
;Y16
;---
  else if name eq ldy16                 ;Y16

    if addrmode = 0
      dw addrmode+OP_LDY16
      dw i
      
    else if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_LDY16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_LDY16
      dd i

    end if

;---
;Y32
;---
  else if name eq ldy32 | name eq ldy   ;Y32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_LDY32
      db i

    else if addrmode = 0 | addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_LDY32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      CPY
;---------------

;--
;Y8
;--
  if name eq cpy8                       ;Y8

    if addrmode = 0 | addrmode =1 | addrmode =2 | addrmode =4 \
    | addrmode =5 | addrmode =7
      dw addrmode+OP_CPY8
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPY8
      dd i

    end if

;---
;Y16
;---
  else if name eq cpy16                 ;Y16

    if addrmode = 0
      dw addrmode+OP_CPY16
      dw i

    else if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_CPY16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPY16
      dd i

    end if

;---
;Y32
;---
  else if name eq cpy32 | name eq cpy   ;Y32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_CPY32
      db i

    else if addrmode = 0 | addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_CPY32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      STY
;---------------

;--
;Y8
;--
  if name eq sty8                       ;Y8

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STY8
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STY8
      dd i

    end if

;---
;Y16
;---
  else if name eq sty16                 ;Y16

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STY16
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STY16
      dd i

    end if

;---
;Y32
;---
  else if name eq sty32 | name eq sty   ;Y32

    if addrmode =1 | addrmode =3 | addrmode =5 \
    | addrmode =6 | addrmode =7 | addrmode =8
      dw addrmode+OP_STY32
      db i

    else if addrmode =9 | addrmode=11 | addrmode=13 | addrmode=14
      dw addrmode+OP_STY32
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      JMP
;---------------

  if name eq jmp

    if addrmode >0 & addrmode <9
      dw addrmode+OP_JMP
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_JMP
      dd i

    end if

  end if

;===============================================================================
;===============================================================================

;---------------
;      JSR
;---------------

  if name eq jsr

    if addrmode >0 & addrmode <9
      dw addrmode+OP_JSR
      db i

    else if addrmode >8 & addrmode <15
      dw addrmode+OP_JSR
      dd i

    end if

  end if

;===============================================================================
;===============================================================================




}    ;END-OF-VERY-LLOONNGG-MACRO TERMINATOR BRACKET  !!!!

;===============================================================================

macro lda8 [p] { common o1.6502 lda8, 101b, p }
macro lda16 [p] { common o1.6502 lda16, 101b, p }
macro lda32 [p] { common o1.6502 lda32, 101b, p }
macro lda [p] { common o1.6502 lda, 101b, p }

macro cmp8 [p] { common o1.6502 cmp8, 110b, p }
macro cmp16 [p] { common o1.6502 cmp16, 110b, p }
macro cmp32 [p] { common o1.6502 cmp32, 110b, p }
macro cmp [p] { common o1.6502 cmp, 110b, p }

macro adc8 [p] { common o1.6502 adc8, 110b, p }
macro adc16 [p] { common o1.6502 adc16, 110b, p }
macro adc32 [p] { common o1.6502 adc32, 110b, p }
macro adc [p] { common o1.6502 adc, 011b, p }

macro sbc8 [p] { common o1.6502 sbc8, 110b, p }
macro sbc16 [p] { common o1.6502 sbc16, 110b, p }
macro sbc32 [p] { common o1.6502 sbc32, 110b, p }
macro sbc [p] { common o1.6502 sbc, 110b, p }

macro add8 [p] { common o1.6502 add8, 110b, p }
macro add16 [p] { common o1.6502 add16, 110b, p }
macro add32 [p] { common o1.6502 add32, 110b, p }
macro add [p] { common o1.6502 add, 110b, p }

macro sub8 [p] { common o1.6502 sub8, 110b, p }
macro sub16 [p] { common o1.6502 sub16, 110b, p }
macro sub32 [p] { common o1.6502 sub32, 110b, p }
macro sub [p] { common o1.6502 sub, 110b, p }

macro mul8 [p] { common o1.6502 mul8, 110b, p }
macro mul16 [p] { common o1.6502 mul16, 110b, p }
macro mul32 [p] { common o1.6502 mul32, 110b, p }
macro mul [p] { common o1.6502 mul, 110b, p }

macro div8 [p] { common o1.6502 div8, 110b, p }
macro div16 [p] { common o1.6502 div16, 110b, p }
macro div32 [p] { common o1.6502 div32, 110b, p }
macro div [p] { common o1.6502 div, 110b, p }

macro bit8 [p] { common o1.6502 bit8, 110b, p }
macro bit16 [p] { common o1.6502 bit16, 110b, p }
macro bit32 [p] { common o1.6502 bit32, 110b, p }
macro bit [p] { common o1.6502 bit, 110b, p }

macro ora8 [p] { common o1.6502 ora8, 110b, p }
macro ora16 [p] { common o1.6502 ora16, 110b, p }
macro ora32 [p] { common o1.6502 ora32, 110b, p }
macro ora [p] { common o1.6502 ora, 110b, p }

macro and8 [p] { common o1.6502 and8, 110b, p }
macro and16 [p] { common o1.6502 and16, 110b, p }
macro and32 [p] { common o1.6502 and32, 110b, p }
macro and [p] { common o1.6502 and, 110b, p }

macro eor8 [p] { common o1.6502 eor8, 110b, p }
macro eor16 [p] { common o1.6502 eor16, 110b, p }
macro eor32 [p] { common o1.6502 eor32, 110b, p }
macro eor [p] { common o1.6502 eor, 110b, p }

macro asl8 [p] { common o1.6502 asl8, 110b, p }
macro asl16 [p] { common o1.6502 asl16, 110b, p }
macro asl32 [p] { common o1.6502 asl32, 110b, p }
macro asl [p] { common o1.6502 asl, 110b, p }

macro lsr8 [p] { common o1.6502 lsr8, 110b, p }
macro lsr16 [p] { common o1.6502 lsr16, 110b, p }
macro lsr32 [p] { common o1.6502 lsr32, 110b, p }
macro lsr [p] { common o1.6502 lsr, 110b, p }

macro rol8 [p] { common o1.6502 rol8, 110b, p }
macro rol16 [p] { common o1.6502 rol16, 110b, p }
macro rol32 [p] { common o1.6502 rol32, 110b, p }
macro rol [p] { common o1.6502 rol, 110b, p }

macro ror8 [p] { common o1.6502 ror8, 110b, p }
macro ror16 [p] { common o1.6502 ror16, 110b, p }
macro ror32 [p] { common o1.6502 ror32, 110b, p }
macro ror [p] { common o1.6502 ror, 110b, p }

macro sta8 [p] { common o1.6502 sta8, 100b, p }
macro sta16 [p] { common o1.6502 sta16, 100b, p }
macro sta32 [p] { common o1.6502 sta32, 100b, p }
macro sta [p] { common o1.6502 sta, 100b, p }

macro stz8 [p] { common o1.6502 stz8, 110b, p }
macro stz16 [p] { common o1.6502 stz16, 110b, p }
macro stz32 [p] { common o1.6502 stz32, 110b, p }
macro stz [p] { common o1.6502 stz, 110b, p }

macro inc8 [p] { common o1.6502 inc8, 110b, p }
macro inc16 [p] { common o1.6502 inc16, 110b, p }
macro inc32 [p] { common o1.6502 inc32, 110b, p }
macro inc [p] { common o1.6502 inc, 110b, p }

macro dec8 [p] { common o1.6502 dec8, 110b, p }
macro dec16 [p] { common o1.6502 dec16, 110b, p }
macro dec32 [p] { common o1.6502 dec32, 110b, p }
macro dec [p] { common o1.6502 dec, 110b, p }



macro ldx8 [p] { common o1.6502 ldx8, 101b, p }
macro ldx16 [p] { common o1.6502 ldx16, 101b, p }
macro ldx32 [p] { common o1.6502 ldx32, 101b, p }
macro ldx [p] { common o1.6502 ldx, 101b, p }

macro cpx8 [p] { common o1.6502 cpx8, 110b, p }
macro cpx16 [p] { common o1.6502 cpx16, 110b, p }
macro cpx32 [p] { common o1.6502 cpx32, 110b, p }
macro cpx [p] { common o1.6502 cpx, 110b, p }

macro stx8 [p] { common o1.6502 stx8, 100b, p }
macro stx16 [p] { common o1.6502 stx16, 100b, p }
macro stx32 [p] { common o1.6502 stx32, 100b, p }
macro stx [p] { common o1.6502 stx, 100b, p }

macro ldy8 [p] { common o1.6502 ldy8, 101b, p }
macro ldy16 [p] { common o1.6502 ldy16, 101b, p }
macro ldy32 [p] { common o1.6502 ldy32, 101b, p }
macro ldy [p] { common o1.6502 ldy, 101b, p }

macro cpy8 [p] { common o1.6502 cpy8, 110b, p }
macro cpy16 [p] { common o1.6502 cpy16, 110b, p }
macro cpy32 [p] { common o1.6502 cpy32, 110b, p }
macro cpy [p] { common o1.6502 cpy, 110b, p }

macro sty8 [p] { common o1.6502 sty8, 100b, p }
macro sty16 [p] { common o1.6502 sty16, 100b, p }
macro sty32 [p] { common o1.6502 sty32, 100b, p }
macro sty [p] { common o1.6502 sty, 100b, p }

macro jmp [p] { common o1.6502 jmp, 100b, p }
macro jsr [p] { common o1.6502 jsr, 100b, p }








;-------------------------------------

org $c000
Start:
PrintPC


nop
res
sei
cli
php
plp
phl
pll
clc
clz
clv
cmi
sec
sez
sev
smi
rts
rti
tax
tax8
tax16
tax32
tay
tay8
tay16
tay32
txa
txa8
txa16
txa32
txy
txy8
txy16
txy32
tya
tya8
tya16
tya32
tyx
tyx8
tyx16
tyx32
pha
pha8
pha16
pha32
phx
phx8
phx16
phx32
phy
phy8
phy16
phy32
pla
pla8
pla16
pla32
plx
plx8
plx16
plx32
ply
ply8
ply16
ply32
ina
ina8
ina16
ina32
inx
inx8
inx16
inx32
iny
iny8
iny16
iny32
dea
dea8
dea16
dea32
dex
dex8
dex16
dex32
dey
dey8
dey16
dey32
cax
cax8
cax16
cax32
cay
cay8
cay16
cay32
cxa
cxa8
cxa16
cxa32
cxy
cxy8
cxy16
cxy32
cya
cya8
cya16
cya32
cyx
cyx8
cyx16
cyx32

jpa
jpx
jpy
jsa
jsx
jsy












;----------
;mode 0 imm
;----------
lda8 =$ff
lda16 =$ffff
lda32 =$ffffffff
lda =$ffffffff

cmp8 =$ff
cmp16 =$ffff
cmp32 =$ffffffff
cmp =$ffffffff

adc8 =$ff
adc16 =$ffff
adc32 =$ffffffff
adc =$ffffffff

sbc8 =$ff
sbc16 =$ffff
sbc32 =$ffffffff
sbc =$ffffffff

add8 =$ff
add16 =$ffff
add32 =$ffffffff
add =$ffffffff

sub8 =$ff
sub16 =$ffff
sub32 =$ffffffff
sub =$ffffffff

mul8 =$ff
mul16 =$ffff
mul32 =$ffffffff
mul =$ffffffff

div8 =$ff
div16 =$ffff
div32 =$ffffffff
div =$ffffffff

bit8 =$ff
bit16 =$ffff
bit32 =$ffffffff
bit =$ffffffff

ora8 =$ff
ora16 =$ffff
ora32 =$ffffffff
ora =$ffffffff

and8 =$ff
and16 =$ffff
and32 =$ffffffff
and =$ffffffff

eor8 =$ff
eor16 =$ffff
eor32 =$ffffffff
eor =$ffffffff

asl8 =$ff
asl16 =$ffff
asl32 =$ffffffff
asl =$ffffffff

lsr8 =$ff
lsr16 =$ffff
lsr32 =$ffffffff
lsr =$ffffffff

rol8 =$ff
rol16 =$ffff
rol32 =$ffffffff
rol =$ffffffff

ror8 =$ff
ror16 =$ffff
ror32 =$ffffffff
ror =$ffffffff

ldx8 =$ff
ldx16 =$ffff
ldx32 =$ffffffff
ldx =$ffffffff

cpx8 =$ff
cpx16 =$ffff
cpx32 =$ffffffff
cpx =$ffffffff


;---------
;mode 1 zp
;---------
jmp $ff
jsr $ff

lda8 $ff
lda16 $ff
lda32 $ff
lda $ff

cmp8 $ff
cmp16 $ff
cmp32 $ff
cmp $ff

adc8 $ff
adc16 $ff
adc32 $ff
adc $ff

sbc8 $ff
sbc16 $ff
sbc32 $ff
sbc $ff

add8 $ff
add16 $ff
add32 $ff
add $ff

sub8 $ff
sub16 $ff
sub32 $ff
sub $ff

mul8 $ff
mul16 $ff
mul32 $ff
mul $ff

div8 $ff
div16 $ff
div32 $ff
div $ff

bit8 $ff
bit16 $ff
bit32 $ff
bit $ff

ora8 $ff
ora16 $ff
ora32 $ff
ora $ff

and8 $ff
and16 $ff
and32 $ff
and $ff

eor8 $ff
eor16 $ff
eor32 $ff
eor $ff

asl8 $ff
asl16 $ff
asl32 $ff
asl $ff

lsr8 $ff
lsr16 $ff
lsr32 $ff
lsr $ff

rol8 $ff
rol16 $ff
rol32 $ff
rol $ff

ror8 $ff
ror16 $ff
ror32 $ff
ror $ff

sta8 $ff
sta16 $ff
sta32 $ff
sta $ff

stz8 $ff
stz16 $ff
stz32 $ff
stz $ff

inc8 $ff
inc16 $ff
inc32 $ff
inc $ff

dec8 $ff
dec16 $ff
dec32 $ff
dec $ff

ldx8 $ff
ldx16 $ff
ldx32 $ff
ldx $ff

cpx8 $ff
cpx16 $ff
cpx32 $ff
cpx $ff

stx8 $ff
stx16 $ff
stx32 $ff
stx $ff


;-----------
;mode 2 zp,x
;-----------
jmp $ff,x
jsr $ff,x

lda8 $ff,x
lda16 $ff,x
lda32 $ff,x
lda $ff,x

cmp8 $ff,x
cmp16 $ff,x
cmp32 $ff,x
cmp $ff,x

adc8 $ff,x
adc16 $ff,x
adc32 $ff,x
adc $ff,x

sbc8 $ff,x
sbc16 $ff,x
sbc32 $ff,x
sbc $ff,x

add8 $ff,x
add16 $ff,x
add32 $ff,x
add $ff,x

sub8 $ff,x
sub16 $ff,x
sub32 $ff,x
sub $ff,x

mul8 $ff,x
mul16 $ff,x
mul32 $ff,x
mul $ff,x

div8 $ff,x
div16 $ff,x
div32 $ff,x
div $ff,x

bit8 $ff,x
bit16 $ff,x
bit32 $ff,x
bit $ff,x

ora8 $ff,x
ora16 $ff,x
ora32 $ff,x
ora $ff,x

and8 $ff,x
and16 $ff,x
and32 $ff,x
and $ff,x

eor8 $ff,x
eor16 $ff,x
eor32 $ff,x
eor $ff,x

asl8 $ff,x
asl16 $ff,x
asl32 $ff,x
asl $ff,x

lsr8 $ff,x
lsr16 $ff,x
lsr32 $ff,x
lsr $ff,x

rol8 $ff,x
rol16 $ff,x
rol32 $ff,x
rol $ff,x

ror8 $ff,x
ror16 $ff,x
ror32 $ff,x
ror $ff,x

sta8 $ff,x
sta16 $ff,x
sta32 $ff,x
sta $ff,x

stz8 $ff,x
stz16 $ff,x
stz32 $ff,x
stz $ff,x

inc8 $ff,x
inc16 $ff,x
inc32 $ff,x
inc $ff,x

dec8 $ff,x
dec16 $ff,x
dec32 $ff,x
dec $ff,x

ldy8 $ff,x
ldy16 $ff,x
ldy32 $ff,x
ldy $ff,x

cpy8 $ff,x
cpy16 $ff,x
cpy32 $ff,x
cpy $ff,x

sty8 $ff,x
sty16 $ff,x
sty32 $ff,x
sty $ff,x


;-----------
;mode 3 zp,y
;-----------
jmp $ff,y
jsr $ff,y

lda8 $ff,y
lda16 $ff,y
lda32 $ff,y
lda $ff,y

cmp8 $ff,y
cmp16 $ff,y
cmp32 $ff,y
cmp $ff,y

adc8 $ff,y
adc16 $ff,y
adc32 $ff,y
adc $ff,y

sbc8 $ff,y
sbc16 $ff,y
sbc32 $ff,y
sbc $ff,y

add8 $ff,y
add16 $ff,y
add32 $ff,y
add $ff,y

sub8 $ff,y
sub16 $ff,y
sub32 $ff,y
sub $ff,y

mul8 $ff,y
mul16 $ff,y
mul32 $ff,y
mul $ff,y

div8 $ff,y
div16 $ff,y
div32 $ff,y
div $ff,y

bit8 $ff,y
bit16 $ff,y
bit32 $ff,y
bit $ff,y

ora8 $ff,y
ora16 $ff,y
ora32 $ff,y
ora $ff,y

and8 $ff,y
and16 $ff,y
and32 $ff,y
and $ff,y

eor8 $ff,y
eor16 $ff,y
eor32 $ff,y
eor $ff,y

asl8 $ff,y
asl16 $ff,y
asl32 $ff,y
asl $ff,y

lsr8 $ff,y
lsr16 $ff,y
lsr32 $ff,y
lsr $ff,y

rol8 $ff,y
rol16 $ff,y
rol32 $ff,y
rol $ff,y

ror8 $ff,y
ror16 $ff,y
ror32 $ff,y
ror $ff,y

sta8 $ff,y
sta16 $ff,y
sta32 $ff,y
sta $ff,y

stz8 $ff,y
stz16 $ff,y
stz32 $ff,y
stz $ff,y

inc8 $ff,y
inc16 $ff,y
inc32 $ff,y
inc $ff,y

dec8 $ff,y
dec16 $ff,y
dec32 $ff,y
dec $ff,y

ldx8 $ff,y
ldx16 $ff,y
ldx32 $ff,y
ldx $ff,y

cpx8 $ff,y
cpx16 $ff,y
cpx32 $ff,y
cpx $ff,y

stx8 $ff,y
stx16 $ff,y
stx32 $ff,y
stx $ff,y


;-------------
;mode 4 (zp,x)
;-------------
jmp ($ff,x)
jsr ($ff,x)

lda8 ($ff,x)
lda16 ($ff,x)
lda32 ($ff,x)
lda ($ff,x)

cmp8 ($ff,x)
cmp16 ($ff,x)
cmp32 ($ff,x)
cmp ($ff,x)

adc8 ($ff,x)
adc16 ($ff,x)
adc32 ($ff,x)
adc ($ff,x)

sbc8 ($ff,x)
sbc16 ($ff,x)
sbc32 ($ff,x)
sbc ($ff,x)

add8 ($ff,x)
add16 ($ff,x)
add32 ($ff,x)
add ($ff,x)

sub8 ($ff,x)
sub16 ($ff,x)
sub32 ($ff,x)
sub ($ff,x)

mul8 ($ff,x)
mul16 ($ff,x)
mul32 ($ff,x)
mul ($ff,x)

div8 ($ff,x)
div16 ($ff,x)
div32 ($ff,x)
div ($ff,x)

bit8 ($ff,x)
bit16 ($ff,x)
bit32 ($ff,x)
bit ($ff,x)

ora8 ($ff,x)
ora16 ($ff,x)
ora32 ($ff,x)
ora ($ff,x)

and8 ($ff,x)
and16 ($ff,x)
and32 ($ff,x)
and ($ff,x)

eor8 ($ff,x)
eor16 ($ff,x)
eor32 ($ff,x)
eor ($ff,x)

asl8 ($ff,x)
asl16 ($ff,x)
asl32 ($ff,x)
asl ($ff,x)

lsr8 ($ff,x)
lsr16 ($ff,x)
lsr32 ($ff,x)
lsr ($ff,x)

rol8 ($ff,x)
rol16 ($ff,x)
rol32 ($ff,x)
rol ($ff,x)

ror8 ($ff,x)
ror16 ($ff,x)
ror32 ($ff,x)
ror ($ff,x)

sta8 ($ff,x)
sta16 ($ff,x)
sta32 ($ff,x)
sta ($ff,x)

stz8 ($ff,x)
stz16 ($ff,x)
stz32 ($ff,x)
stz ($ff,x)

inc8 ($ff,x)
inc16 ($ff,x)
inc32 ($ff,x)
inc ($ff,x)

dec8 ($ff,x)
dec16 ($ff,x)
dec32 ($ff,x)
dec ($ff,x)

ldy8 ($ff,x)
ldy16 ($ff,x)
ldy32 ($ff,x)
ldy ($ff,x)

cpy8 ($ff,x)
cpy16 ($ff,x)
cpy32 ($ff,x)
cpy ($ff,x)

sty8 ($ff,x)
sty16 ($ff,x)
sty32 ($ff,x)
sty ($ff,x)


;-----------
;mode 5 (zp)
;-----------
jmp ($ff)
jsr ($ff)

lda8 ($ff)
lda16 ($ff)
lda32 ($ff)
lda ($ff)

cmp8 ($ff)
cmp16 ($ff)
cmp32 ($ff)
cmp ($ff)

adc8 ($ff)
adc16 ($ff)
adc32 ($ff)
adc ($ff)

sbc8 ($ff)
sbc16 ($ff)
sbc32 ($ff)
sbc ($ff)

add8 ($ff)
add16 ($ff)
add32 ($ff)
add ($ff)

sub8 ($ff)
sub16 ($ff)
sub32 ($ff)
sub ($ff)

mul8 ($ff)
mul16 ($ff)
mul32 ($ff)
mul ($ff)

div8 ($ff)
div16 ($ff)
div32 ($ff)
div ($ff)

bit8 ($ff)
bit16 ($ff)
bit32 ($ff)
bit ($ff)

ora8 ($ff)
ora16 ($ff)
ora32 ($ff)
ora ($ff)

and8 ($ff)
and16 ($ff)
and32 ($ff)
and ($ff)

eor8 ($ff)
eor16 ($ff)
eor32 ($ff)
eor ($ff)

asl8 ($ff)
asl16 ($ff)
asl32 ($ff)
asl ($ff)

lsr8 ($ff)
lsr16 ($ff)
lsr32 ($ff)
lsr ($ff)

rol8 ($ff)
rol16 ($ff)
rol32 ($ff)
rol ($ff)

ror8 ($ff)
ror16 ($ff)
ror32 ($ff)
ror ($ff)

sta8 ($ff)
sta16 ($ff)
sta32 ($ff)
sta ($ff)

stz8 ($ff)
stz16 ($ff)
stz32 ($ff)
stz ($ff)

inc8 ($ff)
inc16 ($ff)
inc32 ($ff)
inc ($ff)

dec8 ($ff)
dec16 ($ff)
dec32 ($ff)
dec ($ff)

ldy8 ($ff)
ldy16 ($ff)
ldy32 ($ff)
ldy ($ff)

cpy8 ($ff)
cpy16 ($ff)
cpy32 ($ff)
cpy ($ff)

sty8 ($ff)
sty16 ($ff)
sty32 ($ff)
sty ($ff)


;-------------
;mode 6 (zp),y
;-------------
jmp ($ff),y
jsr ($ff),y

lda8 ($ff),y
lda16 ($ff),y
lda32 ($ff),y
lda ($ff),y

cmp8 ($ff),y
cmp16 ($ff),y
cmp32 ($ff),y
cmp ($ff),y

adc8 ($ff),y
adc16 ($ff),y
adc32 ($ff),y
adc ($ff),y

sbc8 ($ff),y
sbc16 ($ff),y
sbc32 ($ff),y
sbc ($ff),y

add8 ($ff),y
add16 ($ff),y
add32 ($ff),y
add ($ff),y

sub8 ($ff),y
sub16 ($ff),y
sub32 ($ff),y
sub ($ff),y

mul8 ($ff),y
mul16 ($ff),y
mul32 ($ff),y
mul ($ff),y

div8 ($ff),y
div16 ($ff),y
div32 ($ff),y
div ($ff),y

bit8 ($ff),y
bit16 ($ff),y
bit32 ($ff),y
bit ($ff),y

ora8 ($ff),y
ora16 ($ff),y
ora32 ($ff),y
ora ($ff),y

and8 ($ff),y
and16 ($ff),y
and32 ($ff),y
and ($ff),y

eor8 ($ff),y
eor16 ($ff),y
eor32 ($ff),y
eor ($ff),y

asl8 ($ff),y
asl16 ($ff),y
asl32 ($ff),y
asl ($ff),y

lsr8 ($ff),y
lsr16 ($ff),y
lsr32 ($ff),y
lsr ($ff),y

rol8 ($ff),y
rol16 ($ff),y
rol32 ($ff),y
rol ($ff),y

ror8 ($ff),y
ror16 ($ff),y
ror32 ($ff),y
ror ($ff),y

sta8 ($ff),y
sta16 ($ff),y
sta32 ($ff),y
sta ($ff),y

stz8 ($ff),y
stz16 ($ff),y
stz32 ($ff),y
stz ($ff),y

inc8 ($ff),y
inc16 ($ff),y
inc32 ($ff),y
inc ($ff),y

dec8 ($ff),y
dec16 ($ff),y
dec32 ($ff),y
dec ($ff),y

ldy8 ($ff),y
ldy16 ($ff),y
ldy32 ($ff),y
ldy ($ff),y

cpy8 ($ff),y
cpy16 ($ff),y
cpy32 ($ff),y
cpy ($ff),y

sty8 ($ff),y
sty16 ($ff),y
sty32 ($ff),y
sty ($ff),y


;-----------
;mode 7 sr,s
;-----------
jmp 5,s
jsr 5,s

lda8 5,s
lda16 5,s
lda32 5,s

cmp8 5,s
cmp16 5,s
cmp32 5,s
cmp 5,s

adc8 5,s
adc16 5,s
adc32 5,s
adc 5,s

sbc8 5,s
sbc16 5,s
sbc32 5,s
sbc 5,s

add8 5,s
add16 5,s
add32 5,s
add 5,s

sub8 5,s
sub16 5,s
sub32 5,s
sub 5,s

mul8 5,s
mul16 5,s
mul32 5,s
mul 5,s

div8 5,s
div16 5,s
div32 5,s
div 5,s

bit8 5,s
bit16 5,s
bit32 5,s
bit 5,s

ora8 5,s
ora16 5,s
ora32 5,s
ora 5,s

and8 5,s
and16 5,s
and32 5,s
and 5,s

eor8 5,s
eor16 5,s
eor32 5,s
eor 5,s

asl8 5,s
asl16 5,s
asl32 5,s
asl 5,s

lsr8 5,s
lsr16 5,s
lsr32 5,s
lsr 5,s

rol8 5,s
rol16 5,s
rol32 5,s
rol 5,s

ror8 5,s
ror16 5,s
ror32 5,s
ror 5,s

sta8 5,s
sta16 5,s
sta32 5,s
sta 5,s

stz8 5,s
stz16 5,s
stz32 5,s
stz 5,s

inc8 5,s
inc16 5,s
inc32 5,s
inc 5,s

dec8 5,s
dec16 5,s
dec32 5,s
dec 5,s

ldy8 5,s
ldy16 5,s
ldy32 5,s
ldy 5,s

cpy8 5,s
cpy16 5,s
cpy32 5,s
cpy 5,s

sty8 5,s
sty16 5,s
sty32 5,s
sty 5,s


;---------------
;mode 8 (sr,s),y
;---------------
jmp (5,s),y
jsr (5,s),y

lda8 (5,s),y
lda16 (5,s),y
lda32 (5,s),y

cmp8 (5,s),y
cmp16 (5,s),y
cmp32 (5,s),y
cmp (5,s),y

adc8 (5,s),y
adc16 (5,s),y
adc32 (5,s),y
adc (5,s),y

sbc8 (5,s),y
sbc16 (5,s),y
sbc32 (5,s),y
sbc (5,s),y

add8 (5,s),y
add16 (5,s),y
add32 (5,s),y
add (5,s),y

sub8 (5,s),y
sub16 (5,s),y
sub32 (5,s),y
sub (5,s),y

mul8 (5,s),y
mul16 (5,s),y
mul32 (5,s),y
mul (5,s),y

div8 (5,s),y
div16 (5,s),y
div32 (5,s),y
div (5,s),y

bit8 (5,s),y
bit16 (5,s),y
bit32 (5,s),y
bit (5,s),y

ora8 (5,s),y
ora16 (5,s),y
ora32 (5,s),y
ora (5,s),y

and8 (5,s),y
and16 (5,s),y
and32 (5,s),y
and (5,s),y

eor8 (5,s),y
eor16 (5,s),y
eor32 (5,s),y
eor (5,s),y

asl8 (5,s),y
asl16 (5,s),y
asl32 (5,s),y
asl (5,s),y

lsr8 (5,s),y
lsr16 (5,s),y
lsr32 (5,s),y
lsr (5,s),y

rol8 (5,s),y
rol16 (5,s),y
rol32 (5,s),y
rol (5,s),y

ror8 (5,s),y
ror16 (5,s),y
ror32 (5,s),y
ror (5,s),y

sta8 (5,s),y
sta16 (5,s),y
sta32 (5,s),y
sta (5,s),y

stz8 (5,s),y
stz16 (5,s),y
stz32 (5,s),y
stz (5,s),y

inc8 (5,s),y
inc16 (5,s),y
inc32 (5,s),y
inc (5,s),y

dec8 (5,s),y
dec16 (5,s),y
dec32 (5,s),y
dec (5,s),y

ldy8 (5,s),y
ldy16 (5,s),y
ldy32 (5,s),y
ldy (5,s),y

cpy8 (5,s),y
cpy16 (5,s),y
cpy32 (5,s),y
cpy (5,s),y

sty8 (5,s),y
sty16 (5,s),y
sty32 (5,s),y
sty (5,s),y


;----------
;mode 9 abs
;----------
jmp $c000
jsr $c000

lda8 $c000
lda16 $c000
lda32 $c000

cmp8 $c000
cmp16 $c000
cmp32 $c000
cmp $c000

adc8 $c000
adc16 $c000
adc32 $c000
adc $c000

sbc8 $c000
sbc16 $c000
sbc32 $c000
sbc $c000

add8 $c000
add16 $c000
add32 $c000
add $c000

sub8 $c000
sub16 $c000
sub32 $c000
sub $c000

mul8 $c000
mul16 $c000
mul32 $c000
mul $c000

div8 $c000
div16 $c000
div32 $c000
div $c000

bit8 $c000
bit16 $c000
bit32 $c000
bit $c000

ora8 $c000
ora16 $c000
ora32 $c000
ora $c000

and8 $c000
and16 $c000
and32 $c000
and $c000

eor8 $c000
eor16 $c000
eor32 $c000
eor $c000

asl8 $c000
asl16 $c000
asl32 $c000
asl $c000

lsr8 $c000
lsr16 $c000
lsr32 $c000
lsr $c000

rol8 $c000
rol16 $c000
rol32 $c000
rol $c000

ror8 $c000
ror16 $c000
ror32 $c000
ror $c000

sta8 $c000
sta16 $c000
sta32 $c000
sta $c000

stz8 $c000
stz16 $c000
stz32 $c000
stz $c000

inc8 $c000
inc16 $c000
inc32 $c000
inc $c000

dec8 $c000
dec16 $c000
dec32 $c000
dec $c000

ldy8 $c000
ldy16 $c000
ldy32 $c000
ldy $c000

cpy8 $c000
cpy16 $c000
cpy32 $c000
cpy $c000

sty8 $c000
sty16 $c000
sty32 $c000
sty $c000


;-------------
;mode 10 abs,x
;-------------
jmp $c000,x
jsr $c000,x

lda8 $c000,x
lda16 $c000,x
lda32 $c000,x

cmp8 $c000,x
cmp16 $c000,x
cmp32 $c000,x
cmp $c000,x

adc8 $c000,x
adc16 $c000,x
adc32 $c000,x
adc $c000,x

sbc8 $c000,x
sbc16 $c000,x
sbc32 $c000,x
sbc $c000,x

add8 $c000,x
add16 $c000,x
add32 $c000,x
add $c000,x

sub8 $c000,x
sub16 $c000,x
sub32 $c000,x
sub $c000,x

mul8 $c000,x
mul16 $c000,x
mul32 $c000,x
mul $c000,x

div8 $c000,x
div16 $c000,x
div32 $c000,x
div $c000,x

bit8 $c000,x
bit16 $c000,x
bit32 $c000,x
bit $c000,x

ora8 $c000,x
ora16 $c000,x
ora32 $c000,x
ora $c000,x

and8 $c000,x
and16 $c000,x
and32 $c000,x
and $c000,x

eor8 $c000,x
eor16 $c000,x
eor32 $c000,x
eor $c000,x

asl8 $c000,x
asl16 $c000,x
asl32 $c000,x
asl $c000,x

lsr8 $c000,x
lsr16 $c000,x
lsr32 $c000,x
lsr $c000,x

rol8 $c000,x
rol16 $c000,x
rol32 $c000,x
rol $c000,x

ror8 $c000,x
ror16 $c000,x
ror32 $c000,x
ror $c000,x

sta8 $c000,x
sta16 $c000,x
sta32 $c000,x
sta $c000,x

stz8 $c000,x
stz16 $c000,x
stz32 $c000,x
stz $c000,x

inc8 $c000,x
inc16 $c000,x
inc32 $c000,x
inc $c000,x

dec8 $c000,x
dec16 $c000,x
dec32 $c000,x
dec $c000,x

ldy8 $c000,x
ldy16 $c000,x
ldy32 $c000,x
ldy $c000,x

cpy8 $c000,x
cpy16 $c000,x
cpy32 $c000,x
cpy $c000,x

sty8 $c000,x
sty16 $c000,x
sty32 $c000,x
sty $c000,x


;-------------
;mode 11 abs,y
;-------------
jmp $c000,y
jsr $c000,y

lda8 $c000,y
lda16 $c000,y
lda32 $c000,y

cmp8 $c000,y
cmp16 $c000,y
cmp32 $c000,y
cmp $c000,y

adc8 $c000,y
adc16 $c000,y
adc32 $c000,y
adc $c000,y

sbc8 $c000,y
sbc16 $c000,y
sbc32 $c000,y
sbc $c000,y

add8 $c000,y
add16 $c000,y
add32 $c000,y
add $c000,y

sub8 $c000,y
sub16 $c000,y
sub32 $c000,y
sub $c000,y

mul8 $c000,y
mul16 $c000,y
mul32 $c000,y
mul $c000,y

div8 $c000,y
div16 $c000,y
div32 $c000,y
div $c000,y

bit8 $c000,y
bit16 $c000,y
bit32 $c000,y
bit $c000,y

ora8 $c000,y
ora16 $c000,y
ora32 $c000,y
ora $c000,y

and8 $c000,y
and16 $c000,y
and32 $c000,y
and $c000,y

eor8 $c000,y
eor16 $c000,y
eor32 $c000,y
eor $c000,y

asl8 $c000,y
asl16 $c000,y
asl32 $c000,y
asl $c000,y

lsr8 $c000,y
lsr16 $c000,y
lsr32 $c000,y
lsr $c000,y

rol8 $c000,y
rol16 $c000,y
rol32 $c000,y
rol $c000,y

ror8 $c000,y
ror16 $c000,y
ror32 $c000,y
ror $c000,y

sta8 $c000,y
sta16 $c000,y
sta32 $c000,y
sta $c000,y

stz8 $c000,y
stz16 $c000,y
stz32 $c000,y
stz $c000,y

inc8 $c000,y
inc16 $c000,y
inc32 $c000,y
inc $c000,y

dec8 $c000,y
dec16 $c000,y
dec32 $c000,y
dec $c000,y

ldy8 $c000,y
ldy16 $c000,y
ldy32 $c000,y
ldy $c000,y

cpy8 $c000,y
cpy16 $c000,y
cpy32 $c000,y
cpy $c000,y

sty8 $c000,y
sty16 $c000,y
sty32 $c000,y
sty $c000,y


;-------------
;mode 13 (abs)
;-------------
jmp ($08ffff)
jsr ($08ffff)

lda8 ($08ffff)
lda16 ($08ffff)
lda32 ($08ffff)
lda ($08ffff)

cmp8 ($08ffff)
cmp16 ($08ffff)
cmp32 ($08ffff)
cmp ($08ffff)

adc8 ($08ffff)
adc16 ($08ffff)
adc32 ($08ffff)
adc ($08ffff)

sbc8 ($08ffff)
sbc16 ($08ffff)
sbc32 ($08ffff)
sbc ($08ffff)

add8 ($08ffff)
add16 ($08ffff)
add32 ($08ffff)
add ($08ffff)

sub8 ($08ffff)
sub16 ($08ffff)
sub32 ($08ffff)
sub ($08ffff)

mul8 ($08ffff)
mul16 ($08ffff)
mul32 ($08ffff)
mul ($08ffff)

div8 ($08ffff)
div16 ($08ffff)
div32 ($08ffff)
div ($08ffff)

bit8 ($08ffff)
bit16 ($08ffff)
bit32 ($08ffff)
bit ($08ffff)

ora8 ($08ffff)
ora16 ($08ffff)
ora32 ($08ffff)
ora ($08ffff)

and8 ($08ffff)
and16 ($08ffff)
and32 ($08ffff)
and ($08ffff)

eor8 ($08ffff)
eor16 ($08ffff)
eor32 ($08ffff)
eor ($08ffff)

asl8 ($08ffff)
asl16 ($08ffff)
asl32 ($08ffff)
asl ($08ffff)

lsr8 ($08ffff)
lsr16 ($08ffff)
lsr32 ($08ffff)
lsr ($08ffff)

rol8 ($08ffff)
rol16 ($08ffff)
rol32 ($08ffff)
rol ($08ffff)

ror8 ($08ffff)
ror16 ($08ffff)
ror32 ($08ffff)
ror ($08ffff)

sta8 ($08ffff)
sta16 ($08ffff)
sta32 ($08ffff)
sta ($08ffff)

stz8 ($08ffff)
stz16 ($08ffff)
stz32 ($08ffff)
stz ($08ffff)

inc8 ($08ffff)
inc16 ($08ffff)
inc32 ($08ffff)
inc ($08ffff)

dec8 ($08ffff)
dec16 ($08ffff)
dec32 ($08ffff)
dec ($08ffff)

ldy8 ($08ffff)
ldy16 ($08ffff)
ldy32 ($08ffff)
ldy ($08ffff)

cpy8 ($08ffff)
cpy16 ($08ffff)
cpy32 ($08ffff)
cpy ($08ffff)

sty8 ($08ffff)
sty16 ($08ffff)
sty32 ($08ffff)
sty ($08ffff)


;---------------
;mode 14 (abs),y
;---------------
jmp ($08ffff),y
jsr ($08ffff),y

lda8 ($08ffff),y
lda16 ($08ffff),y
lda32 ($08ffff),y
lda ($08ffff),y

cmp8 ($08ffff),y
cmp16 ($08ffff),y
cmp32 ($08ffff),y
cmp ($08ffff),y

adc8 ($08ffff),y
adc16 ($08ffff),y
adc32 ($08ffff),y
adc ($08ffff),y

sbc8 ($08ffff),y
sbc16 ($08ffff),y
sbc32 ($08ffff),y
sbc ($08ffff),y

add8 ($08ffff),y
add16 ($08ffff),y
add32 ($08ffff),y
add ($08ffff),y

sub8 ($08ffff),y
sub16 ($08ffff),y
sub32 ($08ffff),y
sub ($08ffff),y

mul8 ($08ffff),y
mul16 ($08ffff),y
mul32 ($08ffff),y
mul ($08ffff),y

div8 ($08ffff),y
div16 ($08ffff),y
div32 ($08ffff),y
div ($08ffff),y

bit8 ($08ffff),y
bit16 ($08ffff),y
bit32 ($08ffff),y
bit ($08ffff),y

ora8 ($08ffff),y
ora16 ($08ffff),y
ora32 ($08ffff),y
ora ($08ffff),y

and8 ($08ffff),y
and16 ($08ffff),y
and32 ($08ffff),y
and ($08ffff),y

eor8 ($08ffff),y
eor16 ($08ffff),y
eor32 ($08ffff),y
eor ($08ffff),y

asl8 ($08ffff),y
asl16 ($08ffff),y
asl32 ($08ffff),y
asl ($08ffff),y

lsr8 ($08ffff),y
lsr16 ($08ffff),y
lsr32 ($08ffff),y
lsr ($08ffff),y

rol8 ($08ffff),y
rol16 ($08ffff),y
rol32 ($08ffff),y
rol ($08ffff),y

ror8 ($08ffff),y
ror16 ($08ffff),y
ror32 ($08ffff),y
ror ($08ffff),y

sta8 ($08ffff),y
sta16 ($08ffff),y
sta32 ($08ffff),y
sta ($08ffff),y

stz8 ($08ffff),y
stz16 ($08ffff),y
stz32 ($08ffff),y
stz ($08ffff),y

inc8 ($08ffff),y
inc16 ($08ffff),y
inc32 ($08ffff),y
inc ($08ffff),y

dec8 ($08ffff),y
dec16 ($08ffff),y
dec32 ($08ffff),y
dec ($08ffff),y

ldy8 ($08ffff),y
ldy16 ($08ffff),y
ldy32 ($08ffff),y
ldy ($08ffff),y

cpy8 ($08ffff),y
cpy16 ($08ffff),y
cpy32 ($08ffff),y
cpy ($08ffff),y

sty8 ($08ffff),y
sty16 ($08ffff),y
sty32 ($08ffff),y
sty ($08ffff),y




bra here
here:


;-------------

buffer:






PrintPC



 
